@@ -8,16 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-spot-one", "0.6.147", __name__[0:-6], "cdk-spot-one@0.6.147.jsii.tgz"
+    "cdk-spot-one", "2.0.12", __name__[0:-6], "cdk-spot-one@2.0.12.jsii.tgz"
 )
 
 __all__ = [
